# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v3.0.0
https://git.km3net.de/common/km3net-dataformat
"""

# w2list_km3buu
data = dict(
    W2LIST_KM3BUU_PS=0,
    W2LIST_KM3BUU_EG=1,
    W2LIST_KM3BUU_XSEC_MEAN=2,
    W2LIST_KM3BUU_COLUMN_DEPTH=3,
    W2LIST_KM3BUU_P_EARTH=4,
    W2LIST_KM3BUU_WATER_INT_LEN=5,
    W2LIST_KM3BUU_BX=7,
    W2LIST_KM3BUU_BY=8,
    W2LIST_KM3BUU_ICHAN=9,
    W2LIST_KM3BUU_CC=10,
    W2LIST_KM3BUU_XSEC=13,
    W2LIST_KM3BUU_DXSEC=14,
    W2LIST_KM3BUU_TARGETA=15,
    W2LIST_KM3BUU_TARGETZ=16,
    W2LIST_KM3BUU_VERINCAN=17,
    W2LIST_KM3BUU_LEPINCAN=18,
    W2LIST_KM3BUU_GIBUU_WEIGHT=23,
    W2LIST_KM3BUU_GIBUU_SCAT_TYPE=24,
)
