# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v3.0.0
https://git.km3net.de/common/km3net-dataformat
"""

# trkmembers
data = dict(
    TRK_MOTHER_UNDEFINED=-1,
    TRK_MOTHER_NONE=-2,
    TRK_ST_UNDEFINED=0,
    TRK_ST_FINALSTATE=1,
    TRK_ST_PRIMARYNEUTRINO=100,
    TRK_ST_PRIMARYCOSMIC=200,
    TRK_ST_MUONBUNDLE=300,
    TRK_ST_ININUCLEI=5,
    TRK_ST_INTERSTATE=2,
    TRK_ST_DECSTATE=3,
    TRK_ST_NUCTGT=11,
    TRK_ST_PREHAD=12,
    TRK_ST_PRERES=13,
    TRK_ST_HADNUC=14,
    TRK_ST_NUCLREM=15,
    TRK_ST_NUCLCLT=16,
    TRK_ST_FAKECORSIKA=21,
    TRK_ST_FAKECORSIKA_DEC_MU_START=22,
    TRK_ST_FAKECORSIKA_DEC_MU_END=23,
    TRK_ST_FAKECORSIKA_ETA_2GAMMA=24,
    TRK_ST_FAKECORSIKA_ETA_3PI0=25,
    TRK_ST_FAKECORSIKA_ETA_PIP_PIM_PI0=26,
    TRK_ST_FAKECORSIKA_ETA_2PI_GAMMA=27,
    TRK_ST_FAKECORSIKA_CHERENKOV_GAMMA=28,
    TRK_ST_PROPLEPTON=1001,
    TRK_ST_PROPDECLEPTON=2001,
    PDG_MUONBUNDLE=81,
)
