# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v3.0.0
https://git.km3net.de/common/km3net-dataformat
"""

# daqdatatypes
data = dict(
    DAQSUPERFRAME=101,
    DAQSUMMARYFRAME=201,
    DAQTIMESLICE=1001,
    DAQTIMESLICEL0=1002,
    DAQTIMESLICEL1=1003,
    DAQTIMESLICEL2=1004,
    DAQTIMESLICESN=1005,
    DAQSUMMARYSLICE=2001,
    DAQEVENT=10001,
)
