# -*- coding: utf-8 -*-
"""
KM3NeT Data Definitions v3.0.0
https://git.km3net.de/common/km3net-dataformat
"""

# w2list_genhen
data = dict(
    W2LIST_GENHEN_GLOBAL_GEN_WEIGHT=0,
    W2LIST_GENHEN_EG=1,
    W2LIST_GENHEN_SIG=2,
    W2LIST_GENHEN_COLUMN_DEPTH=3,
    W2LIST_GENHEN_P_EARTH=4,
    W2LIST_GENHEN_REFF=5,
    W2LIST_GENHEN_BX=7,
    W2LIST_GENHEN_BY=8,
    W2LIST_GENHEN_ICHAN=9,
    W2LIST_GENHEN_CC=10,
)
